/****************************************************************************
** Meta object code from reading C++ file 'multiplyinglineeditor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libkdepim-26.07.80/src/multiplyingline/multiplyinglineeditor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'multiplyinglineeditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4KPIM22MultiplyingLineFactoryE_t {};
} // unnamed namespace

template <> constexpr inline auto KPIM::MultiplyingLineFactory::qt_create_metaobjectdata<qt_meta_tag_ZN4KPIM22MultiplyingLineFactoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPIM::MultiplyingLineFactory"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MultiplyingLineFactory, qt_meta_tag_ZN4KPIM22MultiplyingLineFactoryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPIM::MultiplyingLineFactory::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KPIM22MultiplyingLineFactoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KPIM22MultiplyingLineFactoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4KPIM22MultiplyingLineFactoryE_t>.metaTypes,
    nullptr
} };

void KPIM::MultiplyingLineFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MultiplyingLineFactory *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KPIM::MultiplyingLineFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::MultiplyingLineFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KPIM22MultiplyingLineFactoryE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KPIM::MultiplyingLineFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN4KPIM21MultiplyingLineEditorE_t {};
} // unnamed namespace

template <> constexpr inline auto KPIM::MultiplyingLineEditor::qt_create_metaobjectdata<qt_meta_tag_ZN4KPIM21MultiplyingLineEditorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPIM::MultiplyingLineEditor",
        "focusUp",
        "",
        "focusDown",
        "completionModeChanged",
        "KCompletion::CompletionMode",
        "sizeHintChanged",
        "lineDeleted",
        "pos",
        "lineAdded",
        "KPIM::MultiplyingLine*",
        "setFocus",
        "setFocusTop",
        "setFocusBottom"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'focusUp'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusDown'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'completionModeChanged'
        QtMocHelpers::SignalData<void(KCompletion::CompletionMode)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'sizeHintChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lineDeleted'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Signal 'lineAdded'
        QtMocHelpers::SignalData<void(KPIM::MultiplyingLine *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Slot 'setFocus'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setFocusTop'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setFocusBottom'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MultiplyingLineEditor, qt_meta_tag_ZN4KPIM21MultiplyingLineEditorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPIM::MultiplyingLineEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KPIM21MultiplyingLineEditorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KPIM21MultiplyingLineEditorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4KPIM21MultiplyingLineEditorE_t>.metaTypes,
    nullptr
} };

void KPIM::MultiplyingLineEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MultiplyingLineEditor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->focusUp(); break;
        case 1: _t->focusDown(); break;
        case 2: _t->completionModeChanged((*reinterpret_cast<std::add_pointer_t<KCompletion::CompletionMode>>(_a[1]))); break;
        case 3: _t->sizeHintChanged(); break;
        case 4: _t->lineDeleted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->lineAdded((*reinterpret_cast<std::add_pointer_t<KPIM::MultiplyingLine*>>(_a[1]))); break;
        case 6: _t->setFocus(); break;
        case 7: _t->setFocusTop(); break;
        case 8: _t->setFocusBottom(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::MultiplyingLine* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MultiplyingLineEditor::*)()>(_a, &MultiplyingLineEditor::focusUp, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultiplyingLineEditor::*)()>(_a, &MultiplyingLineEditor::focusDown, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultiplyingLineEditor::*)(KCompletion::CompletionMode )>(_a, &MultiplyingLineEditor::completionModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultiplyingLineEditor::*)()>(_a, &MultiplyingLineEditor::sizeHintChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultiplyingLineEditor::*)(int )>(_a, &MultiplyingLineEditor::lineDeleted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultiplyingLineEditor::*)(KPIM::MultiplyingLine * )>(_a, &MultiplyingLineEditor::lineAdded, 5))
            return;
    }
}

const QMetaObject *KPIM::MultiplyingLineEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::MultiplyingLineEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KPIM21MultiplyingLineEditorE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KPIM::MultiplyingLineEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void KPIM::MultiplyingLineEditor::focusUp()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KPIM::MultiplyingLineEditor::focusDown()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KPIM::MultiplyingLineEditor::completionModeChanged(KCompletion::CompletionMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KPIM::MultiplyingLineEditor::sizeHintChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KPIM::MultiplyingLineEditor::lineDeleted(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KPIM::MultiplyingLineEditor::lineAdded(KPIM::MultiplyingLine * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
