/****************************************************************************
** Meta object code from reading C++ file 'progressmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libkdepim-26.07.80/src/progresswidget/progressmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'progressmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4KPIM12ProgressItemE_t {};
} // unnamed namespace

template <> constexpr inline auto KPIM::ProgressItem::qt_create_metaobjectdata<qt_meta_tag_ZN4KPIM12ProgressItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPIM::ProgressItem",
        "progressItemAdded",
        "",
        "KPIM::ProgressItem*",
        "progressItemProgress",
        "progressItemCompleted",
        "progressItemCanceled",
        "progressItemStatus",
        "progressItemLabel",
        "progressItemCryptoStatus",
        "KPIM::ProgressItem::CryptoStatus",
        "progressItemUsesBusyIndicator",
        "item",
        "value"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'progressItemAdded'
        QtMocHelpers::SignalData<void(KPIM::ProgressItem *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'progressItemProgress'
        QtMocHelpers::SignalData<void(KPIM::ProgressItem *, unsigned int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::UInt, 2 },
        }}),
        // Signal 'progressItemCompleted'
        QtMocHelpers::SignalData<void(KPIM::ProgressItem *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'progressItemCanceled'
        QtMocHelpers::SignalData<void(KPIM::ProgressItem *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'progressItemStatus'
        QtMocHelpers::SignalData<void(KPIM::ProgressItem *, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'progressItemLabel'
        QtMocHelpers::SignalData<void(KPIM::ProgressItem *, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'progressItemCryptoStatus'
        QtMocHelpers::SignalData<void(KPIM::ProgressItem *, KPIM::ProgressItem::CryptoStatus)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 10, 2 },
        }}),
        // Signal 'progressItemUsesBusyIndicator'
        QtMocHelpers::SignalData<void(KPIM::ProgressItem *, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 12 }, { QMetaType::Bool, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProgressItem, qt_meta_tag_ZN4KPIM12ProgressItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPIM::ProgressItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KPIM12ProgressItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KPIM12ProgressItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4KPIM12ProgressItemE_t>.metaTypes,
    nullptr
} };

void KPIM::ProgressItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProgressItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->progressItemAdded((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1]))); break;
        case 1: _t->progressItemProgress((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 2: _t->progressItemCompleted((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1]))); break;
        case 3: _t->progressItemCanceled((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1]))); break;
        case 4: _t->progressItemStatus((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->progressItemLabel((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->progressItemCryptoStatus((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem::CryptoStatus>>(_a[2]))); break;
        case 7: _t->progressItemUsesBusyIndicator((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProgressItem::*)(KPIM::ProgressItem * )>(_a, &ProgressItem::progressItemAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressItem::*)(KPIM::ProgressItem * , unsigned int )>(_a, &ProgressItem::progressItemProgress, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressItem::*)(KPIM::ProgressItem * )>(_a, &ProgressItem::progressItemCompleted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressItem::*)(KPIM::ProgressItem * )>(_a, &ProgressItem::progressItemCanceled, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressItem::*)(KPIM::ProgressItem * , const QString & )>(_a, &ProgressItem::progressItemStatus, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressItem::*)(KPIM::ProgressItem * , const QString & )>(_a, &ProgressItem::progressItemLabel, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressItem::*)(KPIM::ProgressItem * , KPIM::ProgressItem::CryptoStatus )>(_a, &ProgressItem::progressItemCryptoStatus, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressItem::*)(KPIM::ProgressItem * , bool )>(_a, &ProgressItem::progressItemUsesBusyIndicator, 7))
            return;
    }
}

const QMetaObject *KPIM::ProgressItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::ProgressItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KPIM12ProgressItemE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KPIM::ProgressItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void KPIM::ProgressItem::progressItemAdded(KPIM::ProgressItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KPIM::ProgressItem::progressItemProgress(KPIM::ProgressItem * _t1, unsigned int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KPIM::ProgressItem::progressItemCompleted(KPIM::ProgressItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KPIM::ProgressItem::progressItemCanceled(KPIM::ProgressItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KPIM::ProgressItem::progressItemStatus(KPIM::ProgressItem * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void KPIM::ProgressItem::progressItemLabel(KPIM::ProgressItem * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void KPIM::ProgressItem::progressItemCryptoStatus(KPIM::ProgressItem * _t1, KPIM::ProgressItem::CryptoStatus _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void KPIM::ProgressItem::progressItemUsesBusyIndicator(KPIM::ProgressItem * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN4KPIM15ProgressManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto KPIM::ProgressManager::qt_create_metaobjectdata<qt_meta_tag_ZN4KPIM15ProgressManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPIM::ProgressManager",
        "progressItemAdded",
        "",
        "KPIM::ProgressItem*",
        "progressItemProgress",
        "progressItemCompleted",
        "progressItemCanceled",
        "progressItemStatus",
        "progressItemLabel",
        "progressItemCryptoStatus",
        "KPIM::ProgressItem::CryptoStatus",
        "progressItemUsesBusyIndicator",
        "showProgressDialog",
        "slotStandardCancelHandler",
        "item",
        "slotAbortAll",
        "slotTransactionCompleted"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'progressItemAdded'
        QtMocHelpers::SignalData<void(KPIM::ProgressItem *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'progressItemProgress'
        QtMocHelpers::SignalData<void(KPIM::ProgressItem *, unsigned int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::UInt, 2 },
        }}),
        // Signal 'progressItemCompleted'
        QtMocHelpers::SignalData<void(KPIM::ProgressItem *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'progressItemCanceled'
        QtMocHelpers::SignalData<void(KPIM::ProgressItem *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'progressItemStatus'
        QtMocHelpers::SignalData<void(KPIM::ProgressItem *, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'progressItemLabel'
        QtMocHelpers::SignalData<void(KPIM::ProgressItem *, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'progressItemCryptoStatus'
        QtMocHelpers::SignalData<void(KPIM::ProgressItem *, KPIM::ProgressItem::CryptoStatus)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 10, 2 },
        }}),
        // Signal 'progressItemUsesBusyIndicator'
        QtMocHelpers::SignalData<void(KPIM::ProgressItem *, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Signal 'showProgressDialog'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStandardCancelHandler'
        QtMocHelpers::SlotData<void(KPIM::ProgressItem *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 14 },
        }}),
        // Slot 'slotAbortAll'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotTransactionCompleted'
        QtMocHelpers::SlotData<void(KPIM::ProgressItem *)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProgressManager, qt_meta_tag_ZN4KPIM15ProgressManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPIM::ProgressManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KPIM15ProgressManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KPIM15ProgressManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4KPIM15ProgressManagerE_t>.metaTypes,
    nullptr
} };

void KPIM::ProgressManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProgressManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->progressItemAdded((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1]))); break;
        case 1: _t->progressItemProgress((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 2: _t->progressItemCompleted((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1]))); break;
        case 3: _t->progressItemCanceled((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1]))); break;
        case 4: _t->progressItemStatus((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->progressItemLabel((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->progressItemCryptoStatus((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem::CryptoStatus>>(_a[2]))); break;
        case 7: _t->progressItemUsesBusyIndicator((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->showProgressDialog(); break;
        case 9: _t->slotStandardCancelHandler((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1]))); break;
        case 10: _t->slotAbortAll(); break;
        case 11: _t->slotTransactionCompleted((*reinterpret_cast<std::add_pointer_t<KPIM::ProgressItem*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::ProgressItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProgressManager::*)(KPIM::ProgressItem * )>(_a, &ProgressManager::progressItemAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressManager::*)(KPIM::ProgressItem * , unsigned int )>(_a, &ProgressManager::progressItemProgress, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressManager::*)(KPIM::ProgressItem * )>(_a, &ProgressManager::progressItemCompleted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressManager::*)(KPIM::ProgressItem * )>(_a, &ProgressManager::progressItemCanceled, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressManager::*)(KPIM::ProgressItem * , const QString & )>(_a, &ProgressManager::progressItemStatus, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressManager::*)(KPIM::ProgressItem * , const QString & )>(_a, &ProgressManager::progressItemLabel, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressManager::*)(KPIM::ProgressItem * , KPIM::ProgressItem::CryptoStatus )>(_a, &ProgressManager::progressItemCryptoStatus, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressManager::*)(KPIM::ProgressItem * , bool )>(_a, &ProgressManager::progressItemUsesBusyIndicator, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProgressManager::*)()>(_a, &ProgressManager::showProgressDialog, 8))
            return;
    }
}

const QMetaObject *KPIM::ProgressManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPIM::ProgressManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KPIM15ProgressManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KPIM::ProgressManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void KPIM::ProgressManager::progressItemAdded(KPIM::ProgressItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KPIM::ProgressManager::progressItemProgress(KPIM::ProgressItem * _t1, unsigned int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KPIM::ProgressManager::progressItemCompleted(KPIM::ProgressItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KPIM::ProgressManager::progressItemCanceled(KPIM::ProgressItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KPIM::ProgressManager::progressItemStatus(KPIM::ProgressItem * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void KPIM::ProgressManager::progressItemLabel(KPIM::ProgressItem * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void KPIM::ProgressManager::progressItemCryptoStatus(KPIM::ProgressItem * _t1, KPIM::ProgressItem::CryptoStatus _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void KPIM::ProgressManager::progressItemUsesBusyIndicator(KPIM::ProgressItem * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void KPIM::ProgressManager::showProgressDialog()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
